@@ -1,29 +1,23 @@
 package Dancer::App;
-our $AUTHORITY = 'cpan:SUKRIA';
-# ABSTRACT: Base application class for Dancer.
-$Dancer::App::VERSION = '1.3514_04'; # TRIAL
-$Dancer::App::VERSION = '1.351404';
+
 use strict;
 use warnings;
-use Carp;
 use base 'Dancer::Object';
 
 use Dancer::Config;
 use Dancer::ModuleLoader;
 use Dancer::Route::Registry;
 use Dancer::Logger;
-use Dancer::Exception qw(:all);
-use Dancer::Deprecation;
 
-Dancer::App->attributes(qw(name app_prefix prefix registry settings on_lexical_prefix));
+Dancer::App->attributes(qw(name prefix registry settings));
 
 # singleton that saves any app created, we want unicity for app names
 my $_apps = {};
 sub applications { values %$_apps }
 
 sub app_exists {
-    my ( $self, $name ) = @_;
-    grep { $_ eq $name } keys %$_apps;
+    my ($self, $name) = @_;
+    grep /^$name$/, keys %$_apps;
 }
 
 sub set_running_app {
@@ -33,53 +27,11 @@ sub set_running_app {
     Dancer::App->current($app);
 }
 
-sub set_app_prefix {
-    my ($self, $prefix) = @_;
-    $self->app_prefix($prefix);
-    $self->prefix($prefix);
-}
-
-sub get_prefix {
-    # return the current prefix (if undefined, return an empty string)
-    return Dancer::App->current->prefix || '';
-}
-
-sub incr_lexical_prefix {
-    no warnings;  # for undefined
-    $_[0]->on_lexical_prefix( $_[0]->on_lexical_prefix + 1 );
-}
-
-sub dec_lexical_prefix {
-    $_[0]->on_lexical_prefix( $_[0]->on_lexical_prefix - 1 );
-}
-
 sub set_prefix {
-    my ($self, $prefix, $cb) = @_;
-
-    undef $prefix if defined($prefix) and $prefix eq "/";
-
-    raise core_app => "not a valid prefix: `$prefix', must start with a /"
+    my ($self, $prefix) = @_;
+    die "not a valid prefix: `$prefix', must start with a /"
       if defined($prefix) && $prefix !~ /^\//;
-
-    my $app_prefix = defined $self->app_prefix ? $self->app_prefix : "";
-    my $previous = Dancer::App->current->prefix;
-
-    $prefix ||= "";
-
-    if (Dancer::App->current->on_lexical_prefix) {
-        Dancer::App->current->prefix($previous.$prefix);
-    } else {
-        Dancer::App->current->prefix($app_prefix.$prefix);
-    }
-
-    if (ref($cb) eq 'CODE') {
-        Dancer::App->current->incr_lexical_prefix;
-        eval { $cb->() };
-        my $e = $@;
-        Dancer::App->current->dec_lexical_prefix;
-        Dancer::App->current->prefix($previous);
-        die $e if $e;
-    }
+    Dancer::App->current->prefix($prefix);
     return 1;    # prefix may have been set to undef
 }
 
@@ -91,15 +43,7 @@ sub routes {
 sub reload_apps {
     my ($class) = @_;
 
-    Dancer::Deprecation->deprecated(
-        feature => 'auto_reload',
-        reason => 'use plackup -r instead',
-    );
-
-    my @missing_modules = grep { not Dancer::ModuleLoader->load($_) }
-        qw(Module::Refresh Clone);
-
-    if (not @missing_modules) {
+    if (Dancer::ModuleLoader->load('Module::Refresh')) {
 
         # saving apps & purging app registries
         my $orig_apps = {};
@@ -119,19 +63,15 @@ sub reload_apps {
 
     }
     else {
-        carp "Modules required for auto_reload are missing. Install modules"
-            . " [@missing_modules] or unset 'auto_reload' in your config file.";
+        warn "Module::Refresh is not installed, "
+          . "install this module or unset 'auto_reload' in your config file";
     }
 }
 
 sub find_route_through_apps {
     my ($class, $request) = @_;
-    for my $app (Dancer::App->current, Dancer::App->applications) {
+    for my $app (Dancer::App->applications) {
         my $route = $app->find_route($request);
-        if ($route) {
-            Dancer::App->current($route->app);
-            return $route;
-        }
         return $route if $route;
     }
     return;
@@ -146,7 +86,7 @@ sub find_route {
     # if route cache is enabled, we check if we handled this path before
     if (Dancer::Config::setting('route_cache')) {
         my $route = Dancer::Route::Cache->get->route_from_path($method,
-            $request->path_info, $self->name);
+            $request->path_info);
 
         # NOTE maybe we should cache the match data as well
         if ($route) {
@@ -166,7 +106,7 @@ sub find_route {
             # if we have a route cache, store the result
             if (Dancer::Config::setting('route_cache')) {
                 Dancer::Route::Cache->get->store_path($method,
-                    $request->path_info => $r, $self->name);
+                    $request->path_info => $r);
             }
 
             return $r;
@@ -179,7 +119,7 @@ sub init {
     my ($self) = @_;
     $self->name('main') unless defined $self->name;
 
-    raise core_app => "an app named '" . $self->name . "' already exists"
+    die "an app named '" . $self->name . "' already exists"
       if exists $_apps->{$self->name};
 
     # default values for properties
@@ -215,60 +155,21 @@ sub get {
 }
 
 sub setting {
-    my $self = shift;
+    my ($self, $name, $value) = @_;
 
     if ($self->name eq 'main') {
-        return (@_ > 1)
-          ? Dancer::Config::setting( @_ )
-          : Dancer::Config::setting( $_[0] );
-    }
-
-    if (@_ > 1) {
-        $self->_set_settings(@_)
-    } else {
-        my $name = shift;
-        exists($self->settings->{$name}) ? $self->settings->{$name}
+        return (@_ == 3)
+          ? Dancer::Config::setting($name => $value)
           : Dancer::Config::setting($name);
     }
-}
 
-sub _set_settings {
-    my $self = shift;
-    die "Odd number of elements in set" unless @_ % 2 == 0;
-    while (@_) {
-        my $name = shift;
-        my $value = shift;
-        $self->settings->{$name} =
-          Dancer::Config->normalize_setting($name => $value);
-    }
+    return
+      (@_ == 3) ? $self->settings->{$name} =
+      $value
+      : (
+        exists($self->settings->{$name}) ? $self->settings->{$name}
+        : Dancer::Config::setting($name)
+      );
 }
 
-
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Dancer::App - Base application class for Dancer.
-
-=head1 VERSION
-
-version 1.3514_04
-
-=head1 AUTHOR
-
-Dancer Core Developers
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Alexis Sukrieh.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
